@@ -86,7 +86,6 @@ def prefix_files(prefix):
             path = join(root, dn)
             if islink(path):
                 res.add(path[len(prefix) + 1:])
-    res = set(utils.expand_globs(res, prefix))
     return res
 
 
@@ -650,9 +649,6 @@ def create_env(prefix, specs, config, clear_cache=True, retry=0):
     with external_logger_context:
         log = logging.getLogger(__name__)
 
-        if os.path.isdir(prefix):
-            utils.rm_rf(prefix)
-
         specs = list(specs)
         for feature, value in feature_list:
             if value:
@@ -810,7 +806,8 @@ def filter_files(files_list, prefix, filter_patterns=('(.*[\\\\/])?\.git[\\\\/].
         r = re.compile(pattern)
         files_list = set(files_list) - set(filter(r.match, files_list))
     return [f.replace(prefix + os.path.sep, '') for f in files_list
-            if not os.path.isdir(os.path.join(prefix, f))]
+            if (not os.path.isdir(os.path.join(prefix, f)) or
+                os.path.islink(os.path.join(prefix, f)))]
 
 
 def post_process_files(m, initial_prefix_files):
@@ -878,7 +875,8 @@ def bundle_conda(output, metadata, config, env, **kw):
         # we exclude the list of files that we want to keep, so post-process picks them up as "new"
         keep_files = set(utils.expand_globs(files, config.build_prefix))
         pfx_files = set(prefix_files(config.build_prefix))
-        initial_files = pfx_files - keep_files
+        initial_files = set(item for item in (pfx_files - keep_files)
+                            if not any(keep_file.startswith(item) for keep_file in keep_files))
 
     files = post_process_files(metadata, initial_files)
 
@@ -1084,7 +1082,7 @@ def build(m, config, post=None, need_source_download=True, need_reparse_in_env=F
             if not has_matches:
                 log.warn("Glob %s from always_include_files does not match any files", pat)
         # Save this for later
-        with open(join(config.croot, 'prefix_files.txt'), 'w') as f:
+        with open(join(m.config.build_folder, 'prefix_files.txt'), 'w') as f:
             f.write(u'\n'.join(sorted(list(files1))))
             f.write(u'\n')
 
@@ -1137,7 +1135,7 @@ def build(m, config, post=None, need_source_download=True, need_reparse_in_env=F
                         utils.check_call_env(cmd, env=env, cwd=src_dir)
 
     if post in [True, None]:
-        with open(join(m.config.croot, 'prefix_files.txt'), 'r') as f:
+        with open(join(m.config.build_folder, 'prefix_files.txt'), 'r') as f:
             initial_files = set(f.read().splitlines())
 
         files = prefix_files(prefix=m.config.build_prefix) - initial_files
@@ -1494,6 +1492,9 @@ def build_tree(recipe_list, config, build_only=False, post=False, notest=False,
                 config.run_recipe_verify_scripts else None
             verifier.verify_recipe(ignore_scripts=ignore_scripts, run_scripts=run_scripts,
                                    rendered_meta=metadata.meta, recipe_dir=metadata.path)
+
+        if metadata.name() not in metadata.config.build_folder and metadata.config.set_build_id:
+            metadata.config.compute_build_id(metadata.name(), reset=True)
         try:
             with config:
                 packages_from_this = build(metadata, post=post,
