@@ -157,14 +157,16 @@ def get_git_info(repo, config):
 
     try:
         output = utils.check_output_env(["git", "describe", "--tags", "--long", "HEAD"],
-                                         env=env, cwd=os.path.dirname(repo),
-                                         stderr=stderr).splitlines()[0]
+                                        env=env, cwd=os.path.dirname(repo),
+                                        stderr=stderr).splitlines()[0]
         output = output.decode('utf-8')
-
         parts = output.rsplit('-', 2)
         if len(parts) == 3:
             d.update(dict(zip(keys, parts)))
+    except subprocess.CalledProcessError:
+        log.warn("Failed to obtain git tag information.  Are you using annotated tags?")
 
+    try:
         # get the _full_ hash of the current HEAD
         output = utils.check_output_env(["git", "rev-parse", "HEAD"],
                                          env=env, cwd=os.path.dirname(repo),
@@ -172,17 +174,17 @@ def get_git_info(repo, config):
         output = output.decode('utf-8')
 
         d['GIT_FULL_HASH'] = output
-        # set up the build string
-        if "GIT_DESCRIBE_NUMBER" in d and "GIT_DESCRIBE_HASH" in d:
-            d['GIT_BUILD_STR'] = '{}_{}'.format(d["GIT_DESCRIBE_NUMBER"],
-                                                d["GIT_DESCRIBE_HASH"])
-
-        # issues on Windows with the next line of the command prompt being recorded here.
-        assert not any("\n" in value for value in d.values())
-
     except subprocess.CalledProcessError as error:
-        log.warn("Error obtaining git information in get_git_info.  Error was: ")
+        log.warn("Error obtaining git commit information.  Error was: ")
         log.warn(str(error))
+
+    # set up the build string
+    if "GIT_DESCRIBE_NUMBER" in d and "GIT_DESCRIBE_HASH" in d:
+        d['GIT_BUILD_STR'] = '{}_{}'.format(d["GIT_DESCRIBE_NUMBER"],
+                                            d["GIT_DESCRIBE_HASH"])
+
+    # issues on Windows with the next line of the command prompt being recorded here.
+    assert not any("\n" in value for value in d.values())
     return d
 
 
@@ -378,8 +380,35 @@ def windows_vars(prefix):
         'LIBRARY_LIB': join(library_prefix, 'lib'),
         'R': join(prefix, 'Scripts', 'R.exe'),
         'CYGWIN_PREFIX': ''.join(('/cygdrive/', drive.lower(), tail.replace('\\', '/'))),
-        'SYSTEMROOT': os.getenv('SYSTEMROOT'),
-        'WINDIR': os.getenv('WINDIR'),
+        # see https://en.wikipedia.org/wiki/Environment_variable#Default_values
+        'ALLUSERSPROFILE': os.getenv('ALLUSERSPROFILE'),
+        'APPDATA': os.getenv('APPDATA'),
+        'CommonProgramFiles': os.getenv('CommonProgramFiles'),
+        'CommonProgramFiles(x86)': os.getenv('CommonProgramFiles(x86)'),
+        'CommonProgramW6432': os.getenv('CommonProgramW6432'),
+        'COMPUTERNAME': os.getenv('COMPUTERNAME'),
+        'ComSpec': os.getenv('ComSpec'),
+        'HOMEDRIVE': os.getenv('HOMEDRIVE'),
+        'HOMEPATH': os.getenv('HOMEPATH'),
+        'LOCALAPPDATA': os.getenv('LOCALAPPDATA'),
+        'LOGONSERVER': os.getenv('LOGONSERVER'),
+        'NUMBER_OF_PROCESSORS': os.getenv('NUMBER_OF_PROCESSORS'),
+        'PATHEXT': os.getenv('PATHEXT'),
+        'ProgramData': os.getenv('ProgramData'),
+        'ProgramFiles': os.getenv('ProgramFiles'),
+        'ProgramFiles(x86)': os.getenv('ProgramFiles(x86)'),
+        'ProgramW6432': os.getenv('ProgramW6432'),
+        'PROMPT': os.getenv('PROMPT'),
+        'PSModulePath': os.getenv('PSModulePath'),
+        'PUBLIC': os.getenv('PUBLIC'),
+        'SystemDrive': os.getenv('SystemDrive'),
+        'SystemRoot': os.getenv('SystemRoot'),
+        'TEMP': os.getenv('TEMP'),
+        'TMP': os.getenv('TMP'),
+        'USERDOMAIN': os.getenv('USERDOMAIN'),
+        'USERNAME': os.getenv('USERNAME'),
+        'USERPROFILE': os.getenv('USERPROFILE'),
+        'windir': os.getenv('windir'),
     }
 
 
