@@ -77,8 +77,9 @@ def update_index(dir_path, config, force=False, check_md5=False, remove=True, lo
     if not lock:
         lock = get_lock(dir_path)
 
+    locks = []
     if config.locking:
-        locks = [lock]
+        locks.append(lock)
 
     with try_acquire_locks(locks, config.timeout):
         if force:
