@@ -1,13 +1,15 @@
 from __future__ import absolute_import, division, print_function
 
+import copy
 import os
 from os.path import isfile, join
 import re
+import six
 import sys
 
 from .conda_interface import iteritems, PY3, text_type
 from .conda_interface import memoized, md5_file
-from .conda_interface import non_x86_linux_machines, platform, arch_name
+from .conda_interface import non_x86_linux_machines, cc_platform, arch_name
 from .conda_interface import MatchSpec
 from .conda_interface import specs_from_url
 
@@ -89,6 +91,32 @@ def ns_cfg(config):
 sel_pat = re.compile(r'(.+?)\s*(#.*)?\[([^\[\]]+)\](?(2).*)$')
 
 
+# this function extracts the variable name from a NameError exception, it has the form of:
+# "NameError: name 'var' is not defined", where var is the variable that is not defined. This gets
+#    returned
+def parseNameNotFound(error):
+    m = re.search('\'(.+?)\'', str(error))
+    if len(m.groups()) == 1:
+        return m.group(1)
+    else:
+        return ""
+
+
+# We evaluate the selector and return True (keep this line) or False (drop this line)
+# If we encounter a NameError (unknown variable in selector), then we replace it by False and
+#     re-run the evaluation
+def eval_selector(selector_string, namespace):
+    try:
+        # TODO: is there a way to do this without eval?  Eval allows arbitrary
+        #    code execution.
+        return eval(selector_string, namespace, {})
+    except NameError as e:
+        missing_var = parseNameNotFound(e)
+        print("Warning: Treating unknown selector \'" + missing_var + "\' as if it was False.")
+        next_string = selector_string.replace(missing_var, "False")
+        return eval_selector(next_string, namespace)
+
+
 def select_lines(data, namespace):
     lines = []
 
@@ -106,9 +134,7 @@ def select_lines(data, namespace):
         if m:
             cond = m.group(3)
             try:
-                # TODO: is there a way to do this without eval?  Eval allows arbitrary
-                #    code execution.
-                if eval(cond, namespace, {}):
+                if eval_selector(cond, namespace):
                     lines.append(m.group(1) + trailing_quote)
             except:
                 sys.exit('''\
@@ -267,6 +293,7 @@ def _git_clean(source_meta):
 
     return ret_meta
 
+
 # If you update this please update the example in
 # conda-docs/docs/source/build.rst
 FIELDS = {
@@ -352,7 +379,7 @@ def build_string_from_metadata(metadata):
                     ('perl', 'pl'), ('lua', 'lua'),
                     ('r', 'r'), ('r-base', 'r')):
         for ms in metadata.ms_depends():
-            if ms.name == name:
+            if ms.name.split(' ')[0] == name:
                 try:
                     v = ms.spec.split()[1]
                 except IndexError:
@@ -410,6 +437,16 @@ class MetaData(object):
         self.parse_again(config=config, permit_undefined_jinja=True)
         self.config.disable_pip = self.disable_pip
 
+    @property
+    def final(self):
+        return self.get_value('extra/final')
+
+    @final.setter
+    def final(self, boolean):
+        extra = self.meta.get('extra', {})
+        extra['final'] = boolean
+        self.meta['extra'] = extra
+
     @property
     def disable_pip(self):
         return 'build' in self.meta and 'disable_pip' in self.meta['build']
@@ -555,8 +592,8 @@ class MetaData(object):
         if res is None:
             sys.exit("Error: package/version missing in: %r" % self.meta_path)
         check_bad_chrs(res, 'package/version')
-        assert self.undefined_jinja_vars or not res.startswith('.'), "Fully-rendered version can't\
-        start with leading period -  got %s" % res
+        if self.final and res.startswith('.'):
+            raise ValueError("Fully-rendered version can't start with period -  got %s", res)
         return res
 
     def build_number(self):
@@ -650,7 +687,7 @@ class MetaData(object):
             version=self.version(),
             build=self.build_id(),
             build_number=self.build_number() if self.build_number() else 0,
-            platform=platform,
+            platform=cc_platform,
             arch=arch_name,
             subdir=self.config.subdir,
             depends=sorted(' '.join(ms.spec.split())
@@ -661,11 +698,11 @@ class MetaData(object):
             if value:
                 d[key] = value
 
-        build_noarch = self.get_value('build/noarch')
         if self.get_value('build/features'):
             d['features'] = ' '.join(self.get_value('build/features'))
         if self.get_value('build/track_features'):
             d['track_features'] = ' '.join(self.get_value('build/track_features'))
+        build_noarch = self.get_value('build/noarch')
         if self.get_value('build/noarch_python') or build_noarch:
             d['platform'] = d['arch'] = None
             d['subdir'] = 'noarch'
@@ -883,3 +920,97 @@ class MetaData(object):
         if any('-' in feature for feature in ensure_list(self.get_value('build/features'))):
             raise ValueError("- is a disallowed character in features.  Please change this "
                              "character in your recipe.")
+
+    def copy(self):
+        new = copy.copy(self)
+        new.config = self.config.copy()
+        new.meta = copy.deepcopy(self.meta)
+        return new
+
+    @property
+    def noarch(self):
+        return self.get_value('build/noarch')
+
+    @noarch.setter
+    def noarch(self, value):
+        build = self.meta.get('build', {})
+        build['noarch'] = value
+        self.meta['build'] = build
+        if not self.noarch_python and not value:
+            self.config.reset_platform()
+        elif value:
+            self.config.platform = 'noarch'
+
+    @property
+    def noarch_python(self):
+        return self.get_value('build/noarch_python')
+
+    @noarch_python.setter
+    def noarch_python(self, value):
+        build = self.meta.get('build', {})
+        build['noarch_python'] = value
+        self.meta['build'] = build
+        if not self.noarch and not value:
+            self.config.reset_platform()
+        elif value:
+            self.config.platform = 'noarch'
+
+    def get_output_metadata(self, output):
+        output_metadata = self.copy()
+        output_metadata.meta['package']['name'] = output.get('name', self.name())
+        requirements = output_metadata.meta.get('requirements', {})
+        requirements['run'] = output.get('requirements', [])
+        output_metadata.meta['requirements'] = requirements
+        output_metadata.meta['package']['version'] = output.get('version') or self.version()
+        if self.name() != output_metadata.name():
+            extra = self.meta.get('extra', {})
+            extra['parent_recipe'] = {'path': self.path, 'name': self.name(),
+                                      'version': self.version()}
+            output_metadata.meta['extra'] = extra
+        output_metadata.noarch = output.get('noarch')
+        output_metadata.noarch_python = output.get('noarch_python')
+        return output_metadata
+
+    def get_output_metadata_set(self, files, permit_undefined_jinja=False):
+        outputs = self.get_section('outputs')
+
+        # this is the old, default behavior: conda package, with difference between start
+        #    set of files and end set of files
+        requirements = self.get_value('requirements/run')
+        try:
+            if not outputs:
+                outputs = [{'name': self.name(),
+                            'files': files,
+                            'requirements': requirements,
+                            'noarch_python': self.get_value('build/noarch_python'),
+                            'noarch': self.get_value('build/noarch')}]
+            else:
+                # make a metapackage for the top-level package if the top-level requirements
+                #     mention a subpackage,
+                uses_subpackage = any(out.get('name') in requirements for out in outputs)
+                # but only if a matching output name is not explicitly provided
+                if uses_subpackage and not any(self.name() == out.get('name', '')
+                                               for out in outputs):
+
+                    outputs.append({'name': self.name(), 'requirements': requirements,
+                                    'pin_downstream':
+                                        self.meta.get('build', {}).get('pin_downstream'),
+                                    'noarch_python': self.get_value('build/noarch_python'),
+                                    'noarch': self.get_value('build/noarch'),
+                                    })
+            for out in outputs:
+                if (self.name() == out.get('name', '') and not (out.get('files') or
+                                                                out.get('script'))):
+                    if files:
+                        out['files'] = files
+                    out['requirements'] = requirements
+                    out['noarch_python'] = out.get('noarch_python',
+                                                    self.get_value('build/noarch_python'))
+                    out['noarch'] = out.get('noarch', self.get_value('build/noarch'))
+                metadata = [self.get_output_metadata(output) for output in outputs]
+        except SystemExit:
+            if not permit_undefined_jinja:
+                raise
+            outputs = []
+            metadata = []
+        return list(six.moves.zip(outputs, metadata))
